pub struct SendHandle {
pub created_at: MilliSecondsSinceUnixEpoch,
/* private fields */
}Expand description
A handle to manipulate an event that was scheduled to be sent to a room.
The event may be a room message, a media upload, a redaction or a reaction;
Self::edit and Self::react only apply to the first two, and return
false/None for the others.
Fields
created_at: MilliSecondsSinceUnixEpochThe time at which the event to be sent has been created.
Implementations
Sourceimpl SendHandle
impl SendHandle
Sourcepub fn transaction_id(&self) -> &TransactionId
pub fn transaction_id(&self) -> &TransactionId
Returns the TransactionId used for sending the associated event.
Sourcepub async fn abort(&self) -> Result<bool, RoomSendQueueStorageError>
pub async fn abort(&self) -> Result<bool, RoomSendQueueStorageError>
Aborts the sending of the event, if it wasn’t sent yet.
Returns true if the sending could be aborted, false if not (i.e. the event had already been sent).
Sourcepub async fn abort_with_reason(
&self,
reason: Option<String>,
) -> Result<bool, RoomSendQueueStorageError>
pub async fn abort_with_reason( &self, reason: Option<String>, ) -> Result<bool, RoomSendQueueStorageError>
Aborts the sending of the event, if it wasn’t sent yet, with an optional reason.
If the event was being sent when the abort was requested and the send succeeds, the event is redacted server-side; the given reason is applied to that redaction. It is unused in every other case (the local echo is simply dropped).
Returns true if the sending could be aborted, false if not (i.e. the event had already been sent).
Sourcepub async fn edit_raw(
&self,
new_content: Raw<AnyMessageLikeEventContent>,
event_type: String,
) -> Result<bool, RoomSendQueueStorageError>
pub async fn edit_raw( &self, new_content: Raw<AnyMessageLikeEventContent>, event_type: String, ) -> Result<bool, RoomSendQueueStorageError>
Edits the content of a local echo with a raw event content.
Returns true if the event to be sent was replaced, false if not (i.e. the event had already been sent).
This method should not be used for editing sticky events. Sticky events
are collected in an ephemeral map. Entries in that map need to be
updated by sending a replacing sticky event with updated content,
not by using an m.replace relation. Nevertheless, this method
applies edits of an unsent sticky event on the queued event
directly because it is safe to do so. If, however, the event has
already been sent, the edit will be sent as an unsticky event.
Sourcepub async fn edit(
&self,
new_content: AnyMessageLikeEventContent,
) -> Result<bool, RoomSendQueueStorageError>
pub async fn edit( &self, new_content: AnyMessageLikeEventContent, ) -> Result<bool, RoomSendQueueStorageError>
Edits the content of a local echo with an event content.
Returns true if the event to be sent was replaced, false if not (i.e. the event had already been sent).
This method should not be used for editing sticky events. Sticky events
are collected in an ephemeral map. Entries in that map need to be
updated by sending a replacing sticky event with updated content,
not by using an m.replace relation. Nevertheless, this method
applies edits of an unsent sticky event on the queued event
directly because it is safe to do so. If, however, the event has
already been sent, the edit will be sent as an unsticky event.
Sourcepub async fn edit_media_caption(
&self,
caption: Option<String>,
formatted_caption: Option<FormattedBody>,
mentions: Option<Mentions>,
) -> Result<bool, RoomSendQueueStorageError>
pub async fn edit_media_caption( &self, caption: Option<String>, formatted_caption: Option<FormattedBody>, mentions: Option<Mentions>, ) -> Result<bool, RoomSendQueueStorageError>
Edits the content of a local echo with a media caption.
Will fail if the event to be sent, represented by this send handle, wasn’t a media.
Sourcepub async fn unwedge(&self) -> Result<(), RoomSendQueueError>
pub async fn unwedge(&self) -> Result<(), RoomSendQueueError>
Unwedge the local echo associated to this SendHandle and try to
resend it.
Sourcepub async fn react(
&self,
key: String,
) -> Result<Option<SendHandle>, RoomSendQueueStorageError>
pub async fn react( &self, key: String, ) -> Result<Option<SendHandle>, RoomSendQueueStorageError>
Send a reaction to the event as soon as it’s sent.
If returning Ok(None); this means the reaction couldn’t be sent
because the event is already a remote one.